Colors - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Documentation

# Colors

Bootstrap documentation

The choice of colors for a website or app interface has an big influence on how users interact with the product and what decisions they make. Harmonic colors can contribute to a nice first impression and encourage users to engage with your product, so it's a very important aspect of a successful design, which needs to be well thought out.

## Base colors

Choose one of the available colors from the basic color palette and make your design attractive for users. You can use the colors to customize the design of components, indicate different states or suggest actions you want users to take.

B
Blue
`bg-blue`
A
Azure
`bg-azure`
I
Indigo
`bg-indigo`
P
Purple
`bg-purple`
P
Pink
`bg-pink`
R
Red
`bg-red`
O
Orange
`bg-orange`
Y
Yellow
`bg-yellow`
L
Lime
`bg-lime`
G
Green
`bg-green`
T
Teal
`bg-teal`
C
Cyan
`bg-cyan`

## Light colors

All available colors can come in pastel shades, which are perfect for more subtle designs and can be easily combined with the basic palette to create eye-cathing designs.

B
Blue
`bg-blue-lt`
A
Azure
`bg-azure-lt`
I
Indigo
`bg-indigo-lt`
P
Purple
`bg-purple-lt`
P
Pink
`bg-pink-lt`
R
Red
`bg-red-lt`
O
Orange
`bg-orange-lt`
Y
Yellow
`bg-yellow-lt`
L
Lime
`bg-lime-lt`
G
Green
`bg-green-lt`
T
Teal
`bg-teal-lt`
C
Cyan
`bg-cyan-lt`